/*****************************************************************************
 * Copyright (C) 2014-2018
 *
 * Michiel Broek <mbroek at mbse dot eu>
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * BrewCloud is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ThermFerm; see the file COPYING.  If not, write to the Free
 * Software Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *****************************************************************************/


function createDelElements() {
	$('#eventWindow').jqxWindow({
		theme: theme,
		position: { x: 490, y: 210 },
		width: 300,
		height: 175,
		resizable: false,
		isModal: true,
		modalOpacity: 0.4,
		okButton: $('#delOk'),
		cancelButton: $('#delCancel'),
		initContent: function () {
			$('#delOk').jqxButton({ width: '65px', theme: theme });
			$('#delCancel').jqxButton({ width: '65px', theme: theme });
			$('#delCancel').focus();
		}
	});
	$('#eventWindow').jqxWindow('hide');
}


$(document).ready(function () {
	var url = "includes/db_inventory_miscs.php";
	// prepare the data
	var source = {
		datatype: "json",
		cache: false,
		datafields: [
			{ name: 'record', type: 'number' },
			{ name: 'name', type: 'string' },
			{ name: 'type', type: 'string' },
			{ name: 'use_use', type: 'string' },
			{ name: 'time', type: 'float' },
			{ name: 'amount', type: 'float' },
			{ name: 'amount_is_weight', type: 'bool' },
			{ name: 'use_for', type: 'string' },
			{ name: 'notes', type: 'string' },
			{ name: 'always_on_stock', type: 'bool' },
			{ name: 'inventory', type: 'float' },
			{ name: 'cost', type: 'float' },
			{ name: 'production_date', type: 'string' },
			{ name: 'tht_date', type: 'string' }
		],
		id: 'record',
		url: url,
		deleterow: function (rowid, commit) {
			// synchronize with the server - send delete command
			var data = "delete=true&" + $.param({ record: rowid });
			$.ajax({
				dataType: 'json',
				url: url,
				cache: false,
				data: data,
				success: function (data, status, xhr) {
					// delete command is executed.
					commit(true);
				},
				error: function (jqXHR, textStatus, errorThrown) {
					commit(false);
				}
			});
		},
		addrow: function (rowid, rowdata, position, commit) {
			var data = "insert=true&" + $.param(rowdata);
			$.ajax({
				dataType: 'json',
				url: url,
				cache: false,
				data: data,
				success: function (data, status, xhr) {
					commit(true);
				},
				error: function(jqXHR, textStatus, errorThrown) {
                                        commit(false);
                                }
                        });
                },
		updaterow: function (rowid, rowdata, commit) {
			var data = "update=true&" + $.param(rowdata);
			$.ajax({
				dataType: 'json',
				url: url,
				cache: false,
				data: data,
				success: function (data, status, xhr) {
					// update command is executed.
					commit(true);
				},
				error: function(jqXHR, textStatus, errorThrown) {
					commit(false);
				}
			});
		}
	};
	var srcType = [ "Spice", "Fining", "Water Agent", "Herb", "Flavor", "Yeast nutrient", "Other" ];
	var srcUse = [ "Boil", "Mash", "Primary", "Secondary", "Bottling" ];
	// initialize the input fields.
	$("#name").jqxInput({ theme: theme, width: 250, height: 23 });
	$("#type").jqxDropDownList({ theme: theme, source: srcType, width: 130, height: 23, dropDownHeight: 220 });
	$("#use_use").jqxDropDownList({ theme: theme, source: srcUse, width: 90, height: 23, dropDownHeight: 156 });
	$("#time").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 0, decimalDigits: 2, spinButtons: true });
	$("#amount_is_weight").jqxCheckBox({ theme: theme, width: 120, height: 23 });
	$("#use_for").jqxInput({ theme: theme, width: 640, height: 48 });
	$("#notes").jqxInput({ theme: theme, width: 640, height: 100 });
	$("#always_on_stock").jqxCheckBox({ theme: theme, width: 120, height: 23 });
	$("#inventory").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 0, decimalDigits: 1, spinButtons: true });
	$("#production_date").jqxDateTimeInput({ theme: theme, width: 100, height: 23, formatString: 'yyyy-MM-dd' });
	$("#cost").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 0, decimalDigits: 2, spinButtons: true });
	$("#tht_date").jqxDateTimeInput({ theme: theme, width: 100, height: 23, formatString: 'yyyy-MM-dd' });

	var dataAdapter = new $.jqx.dataAdapter(source);
	var editrow = -1;
	// initialize jqxGrid
	$("#jqxgrid").jqxGrid({
		width: 1280,
		height: 630,
		source: dataAdapter,
		theme: theme,
		showstatusbar: true,
		localization: getLocalization(),
		renderstatusbar: function (statusbar) {
			var container = $("<div style='overflow: hidden; position: relative; margin: 5px;'></div>");
			var addButton = $("<div style='float: right; margin-right: 15px;'><img style='position: relative; margin-top: 2px;' src='images/add.png'/><span style='margin-left: 4px; position: relative; top: -3px;'>Nieuw</span></div>");
			container.append(addButton);
			statusbar.append(container);
			addButton.jqxButton({ theme: theme, width: 120, height: 20 });
			// add new row.
			addButton.click(function (event) {
				editrow = -1;
				$("#popupWindow").jqxWindow({ position: { x: 230, y: 30 } });
				$("#name").val('');
				$("#type").val('');
				$("#use_use").val('');
				$("#time").val('');
				$("#amount_is_weight").val('');
				$("#use_for").val('');
				$("#notes").val('');
				$("#always_on_stock").val('');
				$("#inventory").val('');
				$("#cost").val('');
				$("#production_date").val('');
				$("#tht_date").val('');
				$("#popupWindow").jqxWindow('open');
			});
		},
		filterable: true,
		filtermode: 'excel',
		columns: [
			{ text: 'Ingredient naam', datafield: 'name', width: 525 },
			{ text: 'Soort', datafield: 'type', align: 'center', cellsalign: 'center', width: 110 },
			{ text: 'Gebruik', datafield: 'use_use', align: 'center', cellsalign: 'center', width: 100 },
			{ text: 'Tijd', datafield: 'time', width: 90, align: 'right', cellsalign: 'right', cellsformat: 'f2' },
			{ text: 'Voor. gr/ml.', datafield: 'inventory', width: 110, align: 'right', cellsalign: 'right' },
			{ text: 'Prijs kg/l', datafield: 'cost', width: 90, align: 'right', cellsalign: 'right', cellsformat: 'c2' },
			{ text: 'THT datum', datafield: 'tht_date', width: 100, align: 'center', cellsalign: 'center' },
			{ text: 'Wijzig', datafield: 'Edit', columntype: 'button', align: 'center', cellsrenderer: function () {
				return "Wijzig";
				}, buttonclick: function (row) {
					// open the popup window when the user clicks a button.
					editrow = row;
					$("#popupWindow").jqxWindow({ position: { x: 230, y: 30 } });
					// get the clicked row's data and initialize the input fields.
					var dataRecord = $("#jqxgrid").jqxGrid('getrowdata', editrow);
					$("#name").val(dataRecord.name);
					$("#type").val(dataRecord.type);
					$("#use_use").val(dataRecord.use_use);
					$("#time").val(dataRecord.time);
					$("#amount_is_weight").val(dataRecord.amount_is_weight);
					$("#use_for").val(dataRecord.use_for);
					$("#notes").val(dataRecord.notes);
					$("#always_on_stock").val(dataRecord.always_on_stock);
					$("#inventory").val(dataRecord.inventory);
					$("#cost").val(dataRecord.cost);
					$("#production_date").val(dataRecord.production_date);
					$("#tht_date").val(dataRecord.tht_date);
					// show the popup window.
					$("#popupWindow").jqxWindow('open');
				}
			}
		]
	});
	// initialize the popup window and buttons.
	$("#popupWindow").jqxWindow({
		width: 860, resizable: false, theme: theme, isModal: true, autoOpen: false, cancelButton: $("#Cancel"), modalOpacity: 0.40
	});
	$("#popupWindow").on('open', function () {
		$("#name").jqxInput('selectAll');
	});
	$("#Delete").jqxButton({ theme: theme });
	$("#Delete").click(function () {
		if (editrow >= 0) {
			// Open a popup to confirm this action.
			$('#eventWindow').jqxWindow('open');
			$("#delOk").click(function () {
				var rowID = $('#jqxgrid').jqxGrid('getrowid', editrow);
				$("#jqxgrid").jqxGrid('deleterow', rowID);
			});
		}
		$("#popupWindow").jqxWindow('hide');
	});
	$("#Cancel").jqxButton({ theme: theme });
	$("#Save").jqxButton({ theme: theme });
	// update the edited row when the user clicks the 'Save' button.
	$("#Save").click(function () {
		if (editrow >= 0) {
			var rowID = $('#jqxgrid').jqxGrid('getrowid', editrow);
			var row = {
				record: rowID,
				name: $("#name").val(),
				type: $("#type").val(),
				use_use: $("#use_use").val(),
				time: parseFloat($("#time").jqxNumberInput('decimal')),
				amount_is_weight: $("#amount_is_weight").val(),
				use_for: $("#use_for").val(),
				notes: $("#notes").val(),
				always_on_stock: $("#always_on_stock").val(),
				inventory: parseFloat($("#inventory").jqxNumberInput('decimal')),
				cost: parseFloat($("#cost").jqxNumberInput('decimal')),
		                production_date: $("#production_date").val(),
		                tht_date: $("#tht_date").val()
			};
			$('#jqxgrid').jqxGrid('updaterow', rowID, row);
			$("#popupWindow").jqxWindow('hide');
		} else {
			// Insert a record
			var newrow = {
				record: -1,
				name: $("#name").val(),
				type: $("#type").val(),
				use_use: $("#use_use").val(),
				time: parseFloat($("#time").jqxNumberInput('decimal')),
				amount_is_weight: $("#amount_is_weight").val(),
				use_for: $("#use_for").val(),
				notes: $("#notes").val(),
				always_on_stock: $("#always_on_stock").val(),
				inventory: parseFloat($("#inventory").jqxNumberInput('decimal')),
				cost: parseFloat($("#cost").jqxNumberInput('decimal')),
				production_date: $("#production_date").val(),
				tht_date: $("#tht_date").val()
			};
			$('#jqxgrid').jqxGrid('addrow', null, newrow);
			$("#popupWindow").jqxWindow('hide');
		}
	});
	createDelElements();
});

